@@ -37,7 +37,6 @@
 #include "vinagre-prefs.h"
 #include "vinagre-cache-prefs.h"
 #include "vinagre-plugins-engine.h"
-#include "vinagre-plugin.h"
 #include "vinagre-dirs.h"
 
 typedef struct {
@@ -129,7 +128,7 @@ protocol_combo_changed (GtkComboBox *combo, VinagreConnectDialog *dialog)
 static void
 setup_protocol (VinagreConnectDialog *dialog)
 {
-  GHashTable      *plugins;
+  GHashTable      *extensions;
   GHashTableIter  hash_iter;
   gpointer        key, value;
   GtkTreeIter     tree_iter;
@@ -138,31 +137,31 @@ setup_protocol (VinagreConnectDialog *dialog)
   gint            selected, i;
 
   dialog->protocol_store = gtk_list_store_new (N_PROTOCOLS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_OBJECT, G_TYPE_OBJECT);
-  plugins = vinagre_plugin_engine_get_plugins_by_protocol (vinagre_plugins_engine_get_default ());
+  extensions = vinagre_plugins_engine_get_plugins_by_protocol (vinagre_plugins_engine_get_default ());
   last_protocol = vinagre_cache_prefs_get_string ("connection", "last-protocol", NULL);
 
-  g_hash_table_iter_init (&hash_iter, plugins);
+  g_hash_table_iter_init (&hash_iter, extensions);
   selected = 0;
   i = 0;
   while (g_hash_table_iter_next (&hash_iter, &key, &value)) 
     {
-      gchar         **description;
-      VinagrePlugin *plugin = VINAGRE_PLUGIN (value);
-      GtkWidget     *widget;
+      gchar **description;
+      GtkWidget *widget;
+      VinagreProtocol *ext =  (VinagreProtocol *)value;
 
-      description = vinagre_plugin_get_public_description (plugin);
+      description = vinagre_protocol_get_public_description (ext);
       if (!description || !description[0])
 	continue;
 
-      widget = vinagre_plugin_get_connect_widget (plugin, NULL);
+      widget = vinagre_protocol_get_connect_widget (ext, NULL);
 
       gtk_list_store_append (dialog->protocol_store, &tree_iter);
       gtk_list_store_set (dialog->protocol_store, &tree_iter,
 			  PROTOCOL_NAME, description[0],
 			  PROTOCOL_DESCRIPTION, description[1],
-			  PROTOCOL_MDNS, vinagre_plugin_get_mdns_service (plugin),
+			  PROTOCOL_MDNS, vinagre_protocol_get_mdns_service (ext),
 			  PROTOCOL_OPTIONS, widget,
-			  PROTOCOL_PLUGIN, plugin,
+			  PROTOCOL_PLUGIN, ext,
 			  -1);
 
       if (last_protocol && g_str_equal (last_protocol, description[0]))
@@ -238,7 +237,6 @@ static void
 setup_combo (VinagreConnectDialog *dialog)
 {
   GtkListStore *store;
-  GtkTreeIter   iter;
   GtkEntryCompletion *completion;
   GPtrArray    *history;
   gint          i, size;
@@ -263,7 +261,7 @@ setup_combo (VinagreConnectDialog *dialog)
 
   gtk_combo_box_set_model (GTK_COMBO_BOX (dialog->host_entry),
 			   GTK_TREE_MODEL (store));
-  gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (dialog->host_entry),
+  gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (dialog->host_entry),
 				       0);
 
   completion = gtk_entry_completion_new ();
@@ -286,7 +284,7 @@ save_history (GtkWidget *combo) {
   GString *content;
   GError *error = NULL;
 
-  host = gtk_combo_box_get_active_text (GTK_COMBO_BOX (combo));
+  host = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (combo));
 
   history = saved_history ();
   for (i=0; i<history->len; i++)
@@ -331,7 +329,7 @@ vinagre_connect_find_button_cb (GtkButton            *button,
   GtkTreeIter   tree_iter;
   gchar         *service;
   GtkWidget     *options = NULL;
-  VinagrePlugin *plugin = NULL;
+  VinagreProtocol *plugin = NULL;
 
   if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (dialog->protocol_combo),
 				      &tree_iter))
@@ -381,7 +379,7 @@ vinagre_connect_find_button_cb (GtkButton            *button,
 
       g_free (tmp);
       if (plugin && options)
-	vinagre_plugin_parse_mdns_dialog (plugin, options, d);
+	vinagre_protocol_parse_mdns_dialog (plugin, options, d);
     }
 
   g_free (service);
@@ -391,13 +389,20 @@ vinagre_connect_find_button_cb (GtkButton            *button,
 }
 #endif
 
-VinagreConnection *vinagre_connect (VinagreWindow *window)
+/**
+ * vinagre_connect:
+ * @window: A Window
+ *
+ * Return value: (allow-none) (transfer full):
+ */
+VinagreConnection *
+vinagre_connect (VinagreWindow *window)
 {
   VinagreConnection    *conn = NULL;
   gint                  result;
   VinagreConnectDialog  dialog;
 
-  dialog.xml = vinagre_utils_get_builder (NULL, NULL);
+  dialog.xml = vinagre_utils_get_builder (NULL);
   if (!dialog.xml)
     return NULL;
 
@@ -432,13 +437,13 @@ VinagreConnection *vinagre_connect (VinagreWindow *window)
 
   if (result == GTK_RESPONSE_OK)
     {
-      gchar         *host = NULL, *error_msg = NULL, *protocol = NULL, *actual_host;
-      gint          port;
-      VinagrePlugin *plugin;
-      GtkWidget     *options;
-      GtkTreeIter   iter;
+      gchar *host = NULL, *error_msg = NULL, *protocol = NULL, *actual_host;
+      gint port;
+      GtkWidget *options;
+      GtkTreeIter iter;
+      VinagreProtocol *ext;
 
-      host = gtk_combo_box_get_active_text (GTK_COMBO_BOX (dialog.host_entry));
+      host = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (dialog.host_entry));
       gtk_widget_hide (GTK_WIDGET (dialog.dialog));
 
       if (!host || !g_strcmp0 (host, ""))
@@ -455,14 +460,14 @@ VinagreConnection *vinagre_connect (VinagreWindow *window)
       gtk_tree_model_get (GTK_TREE_MODEL (dialog.protocol_store), &iter,
 			  PROTOCOL_NAME, &protocol,
 			  PROTOCOL_OPTIONS, &options,
-			  PROTOCOL_PLUGIN, &plugin,
+			  PROTOCOL_PLUGIN, &ext,
 		      -1);
 
       vinagre_cache_prefs_set_string ("connection", "last-protocol", protocol);
       g_free (protocol);
       vinagre_cache_prefs_set_boolean ("connection", "fullscreen", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog.fullscreen_check)));
 
-      conn = vinagre_plugin_new_connection (plugin);
+      conn = vinagre_protocol_new_connection (ext);
       if (vinagre_connection_split_string (host,
 					   vinagre_connection_get_protocol (conn),
 					   &protocol,
@@ -488,7 +493,7 @@ VinagreConnection *vinagre_connect (VinagreWindow *window)
 				    GTK_WINDOW (window));
 	}
 
-      g_object_unref (plugin);
+      g_object_unref (ext);
       if (options)
 	g_object_unref (options);
 
