@@ -25,9 +25,11 @@
 #include <errno.h>
 #include <time.h>
 #include <sys/types.h>
+#include <fcntl.h>
 #include <string.h>
 
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "vinagre-window.h"
@@ -40,7 +42,6 @@
 #include "vinagre-ui.h"
 #include "vinagre-window-private.h"
 #include "vinagre-bookmarks-entry.h"
-#include "vinagre-plugin.h"
 #include "vinagre-plugins-engine.h"
 #include "vinagre-dirs.h"
 
@@ -59,10 +60,16 @@ vinagre_window_dispose (GObject *object)
 {
   VinagreWindow *window = VINAGRE_WINDOW (object);
 
+  peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
+
   if (!window->priv->dispose_has_run)
     {
-      vinagre_plugins_engine_deactivate_plugins (vinagre_plugins_engine_get_default (),
-						 window);
+      peas_extension_set_call (window->priv->extensions,
+			       "deactivate",
+			       window);
+
+      g_object_unref (window->priv->extensions);
+      peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
       window->priv->dispose_has_run = TRUE;
     }
 
@@ -81,6 +88,8 @@ vinagre_window_dispose (GObject *object)
       window->priv->update_recents_menu_ui_id = 0;
     }
 
+  peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
+
   G_OBJECT_CLASS (vinagre_window_parent_class)->dispose (object);
 }
 
@@ -194,7 +203,7 @@ vinagre_window_class_init (VinagreWindowClass *klass)
 }
 
 static void
-menu_item_select_cb (GtkItem       *proxy,
+menu_item_select_cb (GtkMenuItem   *proxy,
 		     VinagreWindow *window)
 {
   GtkAction *action;
@@ -213,7 +222,7 @@ menu_item_select_cb (GtkItem       *proxy,
 }
 
 static void
-menu_item_deselect_cb (GtkItem       *proxy,
+menu_item_deselect_cb (GtkMenuItem   *proxy,
                        VinagreWindow *window)
 {
   gtk_statusbar_pop (GTK_STATUSBAR (window->priv->statusbar),
@@ -305,9 +314,8 @@ show_hide_accels (VinagreWindow *window)
 {
   gboolean show_accels;
 
-  g_object_get (vinagre_prefs_get_default (),
-		"show-accels", &show_accels,
-		NULL);
+  show_accels = g_settings_get_boolean (vinagre_prefs_get_default_gsettings (), "show-accels");
+
   g_object_set (gtk_settings_get_default (),
 		"gtk-enable-accels", show_accels,
 		"gtk-enable-mnemonics", show_accels,
@@ -463,8 +471,8 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
 		    G_CALLBACK (recent_manager_changed),
 		    window);
 
-  g_signal_connect_swapped (vinagre_prefs_get_default (),
-			    "notify::show-accels",
+  g_signal_connect_swapped (vinagre_prefs_get_default_gsettings (),
+			    "changed::show-accels",
 			     G_CALLBACK (show_hide_accels),
 			     window);
   show_hide_accels (window);
@@ -493,7 +501,7 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
   GtkAction             *action;
   VinagreWindowPrivate  *p = window->priv;
   VinagreConnection     *conn;
-  VinagrePlugin         *plugin;
+  VinagreProtocol       *ext;
 
   for (l = entries; l; l = l->next)
     {
@@ -531,8 +539,10 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
 
 	  case VINAGRE_BOOKMARKS_ENTRY_NODE_CONN:
 	    conn = vinagre_bookmarks_entry_get_conn (entry);
-	    plugin = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
-								    vinagre_connection_get_protocol (conn));
+	    ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
+								 vinagre_connection_get_protocol (conn));
+	    if (!ext)
+	     continue;
 
 	    action_name = vinagre_connection_get_best_name (conn);
 	    action_label = vinagre_utils_escape_underscores (action_name, -1);
@@ -550,7 +560,7 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
 				     NULL);
 	    g_object_set (G_OBJECT (action),
 			  "icon-name",
-			  vinagre_plugin_get_icon_name (plugin),
+			  vinagre_protocol_get_icon_name (ext),
 			  NULL);
 	    g_object_set_data (G_OBJECT (action), "conn", conn);
 	    gtk_action_group_add_action (p->bookmarks_list_action_group,
@@ -745,10 +755,37 @@ vinagre_window_check_first_run (VinagreWindow *window)
   return FALSE;
 }
 
+static void
+extension_added (PeasExtensionSet *extensions,
+		 PeasPluginInfo   *info,
+		 PeasExtension    *exten,
+		 gpointer          user_data)
+{
+  peas_extension_call (exten, "activate");
+}
+
+static void
+extension_removed (PeasExtensionSet *extensions,
+		   PeasPluginInfo   *info,
+		   PeasExtension    *exten,
+		   gpointer          user_data)
+{
+  peas_extension_call (exten, "deactivate");
+}
+
+static void
+protocol_added_removed_cb (VinagrePluginsEngine *engine,
+			   VinagreProtocol      *protocol,
+			   VinagreWindow        *window)
+{
+  vinagre_window_update_bookmarks_list_menu (window);
+}
+
 static void
 vinagre_window_init (VinagreWindow *window)
 {
   GtkWidget *main_box;
+  VinagrePluginsEngine *engine;
 
   gtk_window_set_default_icon_name ("vinagre");
 
@@ -767,7 +804,7 @@ vinagre_window_init (VinagreWindow *window)
   create_statusbar (window, main_box);
 
   /* Add the main area */
-  window->priv->hpaned = gtk_hpaned_new ();
+  window->priv->hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
   gtk_box_pack_start (GTK_BOX (main_box), 
   		      window->priv->hpaned, 
   		      TRUE, 
@@ -799,13 +836,39 @@ vinagre_window_init (VinagreWindow *window)
                             window);
 #endif
 
-  vinagre_plugins_engine_activate_plugins (vinagre_plugins_engine_get_default (),
-					   window);
+  engine = vinagre_plugins_engine_get_default ();
+  window->priv->extensions = peas_extension_set_new (PEAS_ENGINE (engine),
+						     PEAS_TYPE_ACTIVATABLE,
+						     "object", window,
+						     NULL);
+  g_signal_connect (window->priv->extensions,
+		    "extension-added",
+		    G_CALLBACK (extension_added),
+		    window);
+  g_signal_connect (window->priv->extensions,
+		    "extension-removed",
+		    G_CALLBACK (extension_removed),
+		    window);
+  peas_extension_set_call (window->priv->extensions, "activate");
 
+  g_signal_connect_after (engine,
+			  "protocol-added",
+			  G_CALLBACK (protocol_added_removed_cb),
+			  window);
+  g_signal_connect_after (engine,
+			  "protocol-removed",
+			  G_CALLBACK (protocol_added_removed_cb),
+			  window);
 
   g_idle_add ((GSourceFunc) vinagre_window_check_first_run, window);
 }
 
+/**
+ * vinagre_window_get_notebook:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 VinagreNotebook *
 vinagre_window_get_notebook (VinagreWindow *window)
 {
@@ -863,6 +926,12 @@ vinagre_window_toggle_fullscreen (VinagreWindow *window)
     gtk_window_fullscreen (GTK_WINDOW (window));
 }
 
+/**
+ * vinagre_window_get_statusbar:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_window_get_statusbar (VinagreWindow *window)
 {
@@ -871,6 +940,12 @@ vinagre_window_get_statusbar (VinagreWindow *window)
   return window->priv->statusbar;
 }
 
+/**
+ * vinagre_window_get_toolbar:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_window_get_toolbar (VinagreWindow *window)
 {
@@ -879,6 +954,12 @@ vinagre_window_get_toolbar (VinagreWindow *window)
   return window->priv->toolbar;
 }
 
+/**
+ * vinagre_window_get_menubar:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_window_get_menubar (VinagreWindow *window)
 {
@@ -887,6 +968,12 @@ vinagre_window_get_menubar (VinagreWindow *window)
   return window->priv->menubar;
 }
 
+/**
+ * vinagre_window_get_initialized_action:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkActionGroup *
 vinagre_window_get_initialized_action (VinagreWindow *window)
 {
@@ -895,6 +982,12 @@ vinagre_window_get_initialized_action (VinagreWindow *window)
   return window->priv->machine_initialized_action_group;
 }
 
+/**
+ * vinagre_window_get_always_sensitive_action:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkActionGroup *
 vinagre_window_get_always_sensitive_action (VinagreWindow *window)
 {
@@ -903,6 +996,12 @@ vinagre_window_get_always_sensitive_action (VinagreWindow *window)
   return window->priv->always_sensitive_action_group;
 }
 
+/**
+ * vinagre_window_get_connected_action:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkActionGroup *
 vinagre_window_get_connected_action (VinagreWindow *window)
 {
@@ -911,6 +1010,12 @@ vinagre_window_get_connected_action (VinagreWindow *window)
   return window->priv->machine_connected_action_group;
 }
 
+/**
+ * vinagre_window_get_fav_panel:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_window_get_fav_panel (VinagreWindow *window)
 {
@@ -927,6 +1032,12 @@ vinagre_window_close_active_tab	(VinagreWindow *window)
   vinagre_notebook_close_active_tab (window->priv->notebook);
 }
 
+/**
+ * vinagre_window_get_active_tab:
+ * @window: A window
+ *
+ * Return value: (allow-none) (transfer none):
+ */
 VinagreTab *
 vinagre_window_get_active_tab (VinagreWindow *window)
 {
@@ -935,6 +1046,12 @@ vinagre_window_get_active_tab (VinagreWindow *window)
   return vinagre_notebook_get_active_tab (window->priv->notebook);
 }
 
+/**
+ * vinagre_window_get_ui_manager:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkUIManager *
 vinagre_window_get_ui_manager (VinagreWindow *window)
 {
@@ -953,7 +1070,12 @@ add_connection (VinagreTab *tab, GList **res)
   *res = g_list_prepend (*res, conn);
 }
 
-/* Returns a newly allocated list with all the connections in the window */
+/**
+ * vinagre_window_get_connections: Returns a newly allocated
+ * list with all the connections in the window
+ * 
+ * Return value: (element-type VinagreConnection) (transfer full):
+ */
 GList *
 vinagre_window_get_connections (VinagreWindow *window)
 {
@@ -970,6 +1092,12 @@ vinagre_window_get_connections (VinagreWindow *window)
   return res;
 }
 
+/**
+ * vinagre_window_conn_exists:
+ * @window: A window
+ *
+ * Return value: (allow-none) (transfer none):
+ */
 VinagreTab *
 vinagre_window_conn_exists (VinagreWindow *window, VinagreConnection *conn)
 {
